@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,30 +16,42 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.binaryauthorization_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
+from google.protobuf import timestamp_pb2  # type: ignore
+
 from google.cloud.binaryauthorization_v1.services.binauthz_management_service_v1 import (
     pagers,
 )
-from google.cloud.binaryauthorization_v1.types import resources
-from google.cloud.binaryauthorization_v1.types import service
-from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import BinauthzManagementServiceV1Transport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import BinauthzManagementServiceV1GrpcAsyncIOTransport
+from google.cloud.binaryauthorization_v1.types import resources, service
+
 from .client import BinauthzManagementServiceV1Client
+from .transports.base import DEFAULT_CLIENT_INFO, BinauthzManagementServiceV1Transport
+from .transports.grpc_asyncio import BinauthzManagementServiceV1GrpcAsyncIOTransport
 
 
 class BinauthzManagementServiceV1AsyncClient:
@@ -145,7 +157,7 @@ class BinauthzManagementServiceV1AsyncClient:
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -182,9 +194,9 @@ class BinauthzManagementServiceV1AsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, BinauthzManagementServiceV1Transport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the binauthz management service v1 client.
@@ -228,11 +240,11 @@ class BinauthzManagementServiceV1AsyncClient:
 
     async def get_policy(
         self,
-        request: Union[service.GetPolicyRequest, dict] = None,
+        request: Optional[Union[service.GetPolicyRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Policy:
         r"""A [policy][google.cloud.binaryauthorization.v1.Policy] specifies
@@ -247,8 +259,34 @@ class BinauthzManagementServiceV1AsyncClient:
         [policy][google.cloud.binaryauthorization.v1.Policy] if the
         project does not have one.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import binaryauthorization_v1
+
+            async def sample_get_policy():
+                # Create a client
+                client = binaryauthorization_v1.BinauthzManagementServiceV1AsyncClient()
+
+                # Initialize request argument(s)
+                request = binaryauthorization_v1.GetPolicyRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = await client.get_policy(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (Union[google.cloud.binaryauthorization_v1.types.GetPolicyRequest, dict]):
+            request (Optional[Union[google.cloud.binaryauthorization_v1.types.GetPolicyRequest, dict]]):
                 The request object. Request message for
                 [BinauthzManagementService.GetPolicy][].
             name (:class:`str`):
@@ -272,7 +310,7 @@ class BinauthzManagementServiceV1AsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -313,18 +351,23 @@ class BinauthzManagementServiceV1AsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     async def update_policy(
         self,
-        request: Union[service.UpdatePolicyRequest, dict] = None,
+        request: Optional[Union[service.UpdatePolicyRequest, dict]] = None,
         *,
-        policy: resources.Policy = None,
+        policy: Optional[resources.Policy] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Policy:
         r"""Creates or updates a project's
@@ -336,8 +379,38 @@ class BinauthzManagementServiceV1AsyncClient:
         NOT_FOUND if the project does not exist, INVALID_ARGUMENT if the
         request is malformed.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import binaryauthorization_v1
+
+            async def sample_update_policy():
+                # Create a client
+                client = binaryauthorization_v1.BinauthzManagementServiceV1AsyncClient()
+
+                # Initialize request argument(s)
+                policy = binaryauthorization_v1.Policy()
+                policy.default_admission_rule.evaluation_mode = "ALWAYS_DENY"
+                policy.default_admission_rule.enforcement_mode = "DRYRUN_AUDIT_LOG_ONLY"
+
+                request = binaryauthorization_v1.UpdatePolicyRequest(
+                    policy=policy,
+                )
+
+                # Make the request
+                response = await client.update_policy(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (Union[google.cloud.binaryauthorization_v1.types.UpdatePolicyRequest, dict]):
+            request (Optional[Union[google.cloud.binaryauthorization_v1.types.UpdatePolicyRequest, dict]]):
                 The request object. Request message for
                 [BinauthzManagementService.UpdatePolicy][].
             policy (:class:`google.cloud.binaryauthorization_v1.types.Policy`):
@@ -364,7 +437,7 @@ class BinauthzManagementServiceV1AsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([policy])
         if request is not None and has_flattened_params:
@@ -407,20 +480,25 @@ class BinauthzManagementServiceV1AsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     async def create_attestor(
         self,
-        request: Union[service.CreateAttestorRequest, dict] = None,
+        request: Optional[Union[service.CreateAttestorRequest, dict]] = None,
         *,
-        parent: str = None,
-        attestor_id: str = None,
-        attestor: resources.Attestor = None,
+        parent: Optional[str] = None,
+        attestor_id: Optional[str] = None,
+        attestor: Optional[resources.Attestor] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Attestor:
         r"""Creates an
@@ -432,8 +510,40 @@ class BinauthzManagementServiceV1AsyncClient:
         the [attestor][google.cloud.binaryauthorization.v1.Attestor]
         already exists.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import binaryauthorization_v1
+
+            async def sample_create_attestor():
+                # Create a client
+                client = binaryauthorization_v1.BinauthzManagementServiceV1AsyncClient()
+
+                # Initialize request argument(s)
+                attestor = binaryauthorization_v1.Attestor()
+                attestor.user_owned_grafeas_note.note_reference = "note_reference_value"
+                attestor.name = "name_value"
+
+                request = binaryauthorization_v1.CreateAttestorRequest(
+                    parent="parent_value",
+                    attestor_id="attestor_id_value",
+                    attestor=attestor,
+                )
+
+                # Make the request
+                response = await client.create_attestor(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (Union[google.cloud.binaryauthorization_v1.types.CreateAttestorRequest, dict]):
+            request (Optional[Union[google.cloud.binaryauthorization_v1.types.CreateAttestorRequest, dict]]):
                 The request object. Request message for
                 [BinauthzManagementService.CreateAttestor][].
             parent (:class:`str`):
@@ -476,7 +586,7 @@ class BinauthzManagementServiceV1AsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, attestor_id, attestor])
         if request is not None and has_flattened_params:
@@ -511,18 +621,23 @@ class BinauthzManagementServiceV1AsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     async def get_attestor(
         self,
-        request: Union[service.GetAttestorRequest, dict] = None,
+        request: Optional[Union[service.GetAttestorRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Attestor:
         r"""Gets an
@@ -531,8 +646,34 @@ class BinauthzManagementServiceV1AsyncClient:
         [attestor][google.cloud.binaryauthorization.v1.Attestor] does
         not exist.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import binaryauthorization_v1
+
+            async def sample_get_attestor():
+                # Create a client
+                client = binaryauthorization_v1.BinauthzManagementServiceV1AsyncClient()
+
+                # Initialize request argument(s)
+                request = binaryauthorization_v1.GetAttestorRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = await client.get_attestor(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (Union[google.cloud.binaryauthorization_v1.types.GetAttestorRequest, dict]):
+            request (Optional[Union[google.cloud.binaryauthorization_v1.types.GetAttestorRequest, dict]]):
                 The request object. Request message for
                 [BinauthzManagementService.GetAttestor][].
             name (:class:`str`):
@@ -557,7 +698,7 @@ class BinauthzManagementServiceV1AsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -598,18 +739,23 @@ class BinauthzManagementServiceV1AsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     async def update_attestor(
         self,
-        request: Union[service.UpdateAttestorRequest, dict] = None,
+        request: Optional[Union[service.UpdateAttestorRequest, dict]] = None,
         *,
-        attestor: resources.Attestor = None,
+        attestor: Optional[resources.Attestor] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Attestor:
         r"""Updates an
@@ -618,8 +764,38 @@ class BinauthzManagementServiceV1AsyncClient:
         [attestor][google.cloud.binaryauthorization.v1.Attestor] does
         not exist.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import binaryauthorization_v1
+
+            async def sample_update_attestor():
+                # Create a client
+                client = binaryauthorization_v1.BinauthzManagementServiceV1AsyncClient()
+
+                # Initialize request argument(s)
+                attestor = binaryauthorization_v1.Attestor()
+                attestor.user_owned_grafeas_note.note_reference = "note_reference_value"
+                attestor.name = "name_value"
+
+                request = binaryauthorization_v1.UpdateAttestorRequest(
+                    attestor=attestor,
+                )
+
+                # Make the request
+                response = await client.update_attestor(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (Union[google.cloud.binaryauthorization_v1.types.UpdateAttestorRequest, dict]):
+            request (Optional[Union[google.cloud.binaryauthorization_v1.types.UpdateAttestorRequest, dict]]):
                 The request object. Request message for
                 [BinauthzManagementService.UpdateAttestor][].
             attestor (:class:`google.cloud.binaryauthorization_v1.types.Attestor`):
@@ -647,7 +823,7 @@ class BinauthzManagementServiceV1AsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([attestor])
         if request is not None and has_flattened_params:
@@ -690,25 +866,57 @@ class BinauthzManagementServiceV1AsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     async def list_attestors(
         self,
-        request: Union[service.ListAttestorsRequest, dict] = None,
+        request: Optional[Union[service.ListAttestorsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListAttestorsAsyncPager:
         r"""Lists [attestors][google.cloud.binaryauthorization.v1.Attestor].
         Returns INVALID_ARGUMENT if the project does not exist.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import binaryauthorization_v1
+
+            async def sample_list_attestors():
+                # Create a client
+                client = binaryauthorization_v1.BinauthzManagementServiceV1AsyncClient()
+
+                # Initialize request argument(s)
+                request = binaryauthorization_v1.ListAttestorsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_attestors(request=request)
+
+                # Handle the response
+                async for response in page_result:
+                    print(response)
+
         Args:
-            request (Union[google.cloud.binaryauthorization_v1.types.ListAttestorsRequest, dict]):
+            request (Optional[Union[google.cloud.binaryauthorization_v1.types.ListAttestorsRequest, dict]]):
                 The request object. Request message for
                 [BinauthzManagementService.ListAttestors][].
             parent (:class:`str`):
@@ -736,7 +944,7 @@ class BinauthzManagementServiceV1AsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -777,12 +985,20 @@ class BinauthzManagementServiceV1AsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListAttestorsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -790,11 +1006,11 @@ class BinauthzManagementServiceV1AsyncClient:
 
     async def delete_attestor(
         self,
-        request: Union[service.DeleteAttestorRequest, dict] = None,
+        request: Optional[Union[service.DeleteAttestorRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes an
@@ -803,8 +1019,31 @@ class BinauthzManagementServiceV1AsyncClient:
         [attestor][google.cloud.binaryauthorization.v1.Attestor] does
         not exist.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import binaryauthorization_v1
+
+            async def sample_delete_attestor():
+                # Create a client
+                client = binaryauthorization_v1.BinauthzManagementServiceV1AsyncClient()
+
+                # Initialize request argument(s)
+                request = binaryauthorization_v1.DeleteAttestorRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                await client.delete_attestor(request=request)
+
         Args:
-            request (Union[google.cloud.binaryauthorization_v1.types.DeleteAttestorRequest, dict]):
+            request (Optional[Union[google.cloud.binaryauthorization_v1.types.DeleteAttestorRequest, dict]]):
                 The request object. Request message for
                 [BinauthzManagementService.DeleteAttestor][].
             name (:class:`str`):
@@ -822,7 +1061,7 @@ class BinauthzManagementServiceV1AsyncClient:
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -864,24 +1103,22 @@ class BinauthzManagementServiceV1AsyncClient:
 
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
-    async def __aenter__(self):
+    async def __aenter__(self) -> "BinauthzManagementServiceV1AsyncClient":
         return self
 
     async def __aexit__(self, exc_type, exc, tb):
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-binary-authorization",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("BinauthzManagementServiceV1AsyncClient",)
