@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,15 +19,18 @@ from typing import Dict, Type
 from .base import SystemPolicyV1Transport
 from .grpc import SystemPolicyV1GrpcTransport
 from .grpc_asyncio import SystemPolicyV1GrpcAsyncIOTransport
-
+from .rest import SystemPolicyV1RestInterceptor, SystemPolicyV1RestTransport
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[SystemPolicyV1Transport]]
 _transport_registry["grpc"] = SystemPolicyV1GrpcTransport
 _transport_registry["grpc_asyncio"] = SystemPolicyV1GrpcAsyncIOTransport
+_transport_registry["rest"] = SystemPolicyV1RestTransport
 
 __all__ = (
     "SystemPolicyV1Transport",
     "SystemPolicyV1GrpcTransport",
     "SystemPolicyV1GrpcAsyncIOTransport",
+    "SystemPolicyV1RestTransport",
+    "SystemPolicyV1RestInterceptor",
 )
