@@ -162,7 +162,7 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -1122,7 +1122,7 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
             metadata=metadata,
         )
 
-    async def __aenter__(self):
+    async def __aenter__(self) -> "BinauthzManagementServiceV1Beta1AsyncClient":
         return self
 
     async def __aexit__(self, exc_type, exc, tb):
