@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,7 +19,10 @@ from typing import Dict, Type
 from .base import BinauthzManagementServiceV1Beta1Transport
 from .grpc import BinauthzManagementServiceV1Beta1GrpcTransport
 from .grpc_asyncio import BinauthzManagementServiceV1Beta1GrpcAsyncIOTransport
-
+from .rest import (
+    BinauthzManagementServiceV1Beta1RestInterceptor,
+    BinauthzManagementServiceV1Beta1RestTransport,
+)
 
 # Compile a registry of transports.
 _transport_registry = (
@@ -29,9 +32,12 @@ _transport_registry["grpc"] = BinauthzManagementServiceV1Beta1GrpcTransport
 _transport_registry[
     "grpc_asyncio"
 ] = BinauthzManagementServiceV1Beta1GrpcAsyncIOTransport
+_transport_registry["rest"] = BinauthzManagementServiceV1Beta1RestTransport
 
 __all__ = (
     "BinauthzManagementServiceV1Beta1Transport",
     "BinauthzManagementServiceV1Beta1GrpcTransport",
     "BinauthzManagementServiceV1Beta1GrpcAsyncIOTransport",
+    "BinauthzManagementServiceV1Beta1RestTransport",
+    "BinauthzManagementServiceV1Beta1RestInterceptor",
 )
