@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from __future__ import annotations
+
 from typing import MutableMapping, MutableSequence
 
 from google.protobuf import timestamp_pb2  # type: ignore
@@ -67,7 +69,15 @@ class ContinuousValidationEvent(proto.Message):
         """
 
         class PolicyConformanceVerdict(proto.Enum):
-            r"""Audit time policy conformance verdict."""
+            r"""Audit time policy conformance verdict.
+
+            Values:
+                POLICY_CONFORMANCE_VERDICT_UNSPECIFIED (0):
+                    We should always have a verdict. This is an
+                    error.
+                VIOLATES_POLICY (1):
+                    The pod violates the policy.
+            """
             POLICY_CONFORMANCE_VERDICT_UNSPECIFIED = 0
             VIOLATES_POLICY = 1
 
@@ -84,7 +94,16 @@ class ContinuousValidationEvent(proto.Message):
             """
 
             class AuditResult(proto.Enum):
-                r"""Result of the audit."""
+                r"""Result of the audit.
+
+                Values:
+                    AUDIT_RESULT_UNSPECIFIED (0):
+                        Unspecified result. This is an error.
+                    ALLOW (1):
+                        Image is allowed.
+                    DENY (2):
+                        Image is denied.
+                """
                 AUDIT_RESULT_UNSPECIFIED = 0
                 ALLOW = 1
                 DENY = 2
