@@ -13,10 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
+from __future__ import annotations
+
+from typing import MutableMapping, MutableSequence
 
 from google.protobuf import timestamp_pb2  # type: ignore
-
+import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.cloud.binaryauthorization.v1beta1",
@@ -51,27 +53,27 @@ class Policy(proto.Message):
             project admission policy. This setting has no
             effect when specified inside a global admission
             policy.
-        admission_whitelist_patterns (Sequence[google.cloud.binaryauthorization_v1beta1.types.AdmissionWhitelistPattern]):
+        admission_whitelist_patterns (MutableSequence[google.cloud.binaryauthorization_v1beta1.types.AdmissionWhitelistPattern]):
             Optional. Admission policy allowlisting. A
             matching admission request will always be
             permitted. This feature is typically used to
             exclude Google or third-party infrastructure
             images from Binary Authorization policies.
-        cluster_admission_rules (Mapping[str, google.cloud.binaryauthorization_v1beta1.types.AdmissionRule]):
+        cluster_admission_rules (MutableMapping[str, google.cloud.binaryauthorization_v1beta1.types.AdmissionRule]):
             Optional. Per-cluster admission rules. Cluster spec format:
             ``location.clusterId``. There can be at most one admission
             rule per cluster spec. A ``location`` is either a compute
             zone (e.g. us-central1-a) or a region (e.g. us-central1).
             For ``clusterId`` syntax restrictions see
             https://cloud.google.com/container-engine/reference/rest/v1/projects.zones.clusters.
-        kubernetes_namespace_admission_rules (Mapping[str, google.cloud.binaryauthorization_v1beta1.types.AdmissionRule]):
+        kubernetes_namespace_admission_rules (MutableMapping[str, google.cloud.binaryauthorization_v1beta1.types.AdmissionRule]):
             Optional. Per-kubernetes-namespace admission rules. K8s
             namespace spec format: ``[a-z.-]+``, e.g. ``some-namespace``
-        kubernetes_service_account_admission_rules (Mapping[str, google.cloud.binaryauthorization_v1beta1.types.AdmissionRule]):
+        kubernetes_service_account_admission_rules (MutableMapping[str, google.cloud.binaryauthorization_v1beta1.types.AdmissionRule]):
             Optional. Per-kubernetes-service-account admission rules.
             Service account spec format: ``namespace:serviceaccount``.
             e.g. ``test-ns:default``
-        istio_service_identity_admission_rules (Mapping[str, google.cloud.binaryauthorization_v1beta1.types.AdmissionRule]):
+        istio_service_identity_admission_rules (MutableMapping[str, google.cloud.binaryauthorization_v1beta1.types.AdmissionRule]):
             Optional. Per-istio-service-identity admission rules. Istio
             service identity spec format:
             ``spiffe://<domain>/ns/<namespace>/sa/<serviceaccount>`` or
@@ -88,59 +90,76 @@ class Policy(proto.Message):
     """
 
     class GlobalPolicyEvaluationMode(proto.Enum):
-        r""""""
+        r"""
+
+        Values:
+            GLOBAL_POLICY_EVALUATION_MODE_UNSPECIFIED (0):
+                Not specified: DISABLE is assumed.
+            ENABLE (1):
+                Enables system policy evaluation.
+            DISABLE (2):
+                Disables system policy evaluation.
+        """
         GLOBAL_POLICY_EVALUATION_MODE_UNSPECIFIED = 0
         ENABLE = 1
         DISABLE = 2
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    description = proto.Field(
+    description: str = proto.Field(
         proto.STRING,
         number=6,
     )
-    global_policy_evaluation_mode = proto.Field(
+    global_policy_evaluation_mode: GlobalPolicyEvaluationMode = proto.Field(
         proto.ENUM,
         number=7,
         enum=GlobalPolicyEvaluationMode,
     )
-    admission_whitelist_patterns = proto.RepeatedField(
+    admission_whitelist_patterns: MutableSequence[
+        "AdmissionWhitelistPattern"
+    ] = proto.RepeatedField(
         proto.MESSAGE,
         number=2,
         message="AdmissionWhitelistPattern",
     )
-    cluster_admission_rules = proto.MapField(
+    cluster_admission_rules: MutableMapping[str, "AdmissionRule"] = proto.MapField(
         proto.STRING,
         proto.MESSAGE,
         number=3,
         message="AdmissionRule",
     )
-    kubernetes_namespace_admission_rules = proto.MapField(
+    kubernetes_namespace_admission_rules: MutableMapping[
+        str, "AdmissionRule"
+    ] = proto.MapField(
         proto.STRING,
         proto.MESSAGE,
         number=10,
         message="AdmissionRule",
     )
-    kubernetes_service_account_admission_rules = proto.MapField(
+    kubernetes_service_account_admission_rules: MutableMapping[
+        str, "AdmissionRule"
+    ] = proto.MapField(
         proto.STRING,
         proto.MESSAGE,
         number=8,
         message="AdmissionRule",
     )
-    istio_service_identity_admission_rules = proto.MapField(
+    istio_service_identity_admission_rules: MutableMapping[
+        str, "AdmissionRule"
+    ] = proto.MapField(
         proto.STRING,
         proto.MESSAGE,
         number=9,
         message="AdmissionRule",
     )
-    default_admission_rule = proto.Field(
+    default_admission_rule: "AdmissionRule" = proto.Field(
         proto.MESSAGE,
         number=4,
         message="AdmissionRule",
     )
-    update_time = proto.Field(
+    update_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=5,
         message=timestamp_pb2.Timestamp,
@@ -165,7 +184,7 @@ class AdmissionWhitelistPattern(proto.Message):
             i.e., ``gcr.io/nginx**`` matches ``gcr.io/nginx/image``.
     """
 
-    name_pattern = proto.Field(
+    name_pattern: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -189,7 +208,7 @@ class AdmissionRule(proto.Message):
         evaluation_mode (google.cloud.binaryauthorization_v1beta1.types.AdmissionRule.EvaluationMode):
             Required. How this admission rule will be
             evaluated.
-        require_attestations_by (Sequence[str]):
+        require_attestations_by (MutableSequence[str]):
             Optional. The resource names of the attestors that must
             attest to a container image, in the format
             ``projects/*/attestors/*``. Each attestor must exist before
@@ -206,7 +225,20 @@ class AdmissionRule(proto.Message):
     """
 
     class EvaluationMode(proto.Enum):
-        r""""""
+        r"""
+
+        Values:
+            EVALUATION_MODE_UNSPECIFIED (0):
+                Do not use.
+            ALWAYS_ALLOW (1):
+                This rule allows all all pod creations.
+            REQUIRE_ATTESTATION (2):
+                This rule allows a pod creation if all the attestors listed
+                in ``require_attestations_by`` have valid attestations for
+                all of the images in the pod spec.
+            ALWAYS_DENY (3):
+                This rule denies all pod creations.
+        """
         EVALUATION_MODE_UNSPECIFIED = 0
         ALWAYS_ALLOW = 1
         REQUIRE_ATTESTATION = 2
@@ -215,21 +247,32 @@ class AdmissionRule(proto.Message):
     class EnforcementMode(proto.Enum):
         r"""Defines the possible actions when a pod creation is denied by
         an admission rule.
+
+        Values:
+            ENFORCEMENT_MODE_UNSPECIFIED (0):
+                Do not use.
+            ENFORCED_BLOCK_AND_AUDIT_LOG (1):
+                Enforce the admission rule by blocking the
+                pod creation.
+            DRYRUN_AUDIT_LOG_ONLY (2):
+                Dryrun mode: Audit logging only.  This will
+                allow the pod creation as if the admission
+                request had specified break-glass.
         """
         ENFORCEMENT_MODE_UNSPECIFIED = 0
         ENFORCED_BLOCK_AND_AUDIT_LOG = 1
         DRYRUN_AUDIT_LOG_ONLY = 2
 
-    evaluation_mode = proto.Field(
+    evaluation_mode: EvaluationMode = proto.Field(
         proto.ENUM,
         number=1,
         enum=EvaluationMode,
     )
-    require_attestations_by = proto.RepeatedField(
+    require_attestations_by: MutableSequence[str] = proto.RepeatedField(
         proto.STRING,
         number=2,
     )
-    enforcement_mode = proto.Field(
+    enforcement_mode: EnforcementMode = proto.Field(
         proto.ENUM,
         number=3,
         enum=EnforcementMode,
@@ -261,21 +304,21 @@ class Attestor(proto.Message):
             updated.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    description = proto.Field(
+    description: str = proto.Field(
         proto.STRING,
         number=6,
     )
-    user_owned_drydock_note = proto.Field(
+    user_owned_drydock_note: "UserOwnedDrydockNote" = proto.Field(
         proto.MESSAGE,
         number=3,
         oneof="attestor_type",
         message="UserOwnedDrydockNote",
     )
-    update_time = proto.Field(
+    update_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=4,
         message=timestamp_pb2.Timestamp,
@@ -298,7 +341,7 @@ class UserOwnedDrydockNote(proto.Message):
             ATTESTATION_AUTHORITY Occurrence that names a container
             image and that links to this Note. Drydock is an external
             dependency.
-        public_keys (Sequence[google.cloud.binaryauthorization_v1beta1.types.AttestorPublicKey]):
+        public_keys (MutableSequence[google.cloud.binaryauthorization_v1beta1.types.AttestorPublicKey]):
             Optional. Public keys that verify
             attestations signed by this attestor.  This
             field may be updated.
@@ -323,16 +366,16 @@ class UserOwnedDrydockNote(proto.Message):
             email based on a different naming pattern.
     """
 
-    note_reference = proto.Field(
+    note_reference: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    public_keys = proto.RepeatedField(
+    public_keys: MutableSequence["AttestorPublicKey"] = proto.RepeatedField(
         proto.MESSAGE,
         number=2,
         message="AttestorPublicKey",
     )
-    delegation_service_account_email = proto.Field(
+    delegation_service_account_email: str = proto.Field(
         proto.STRING,
         number=3,
     )
@@ -364,6 +407,44 @@ class PkixPublicKey(proto.Message):
         algorithms. See https://cloud.google.com/kms/docs/algorithms. In
         the future, BinAuthz might support additional public key types
         independently of Tink and/or KMS.
+
+        Values:
+            SIGNATURE_ALGORITHM_UNSPECIFIED (0):
+                Not specified.
+            RSA_PSS_2048_SHA256 (1):
+                RSASSA-PSS 2048 bit key with a SHA256 digest.
+            RSA_PSS_3072_SHA256 (2):
+                RSASSA-PSS 3072 bit key with a SHA256 digest.
+            RSA_PSS_4096_SHA256 (3):
+                RSASSA-PSS 4096 bit key with a SHA256 digest.
+            RSA_PSS_4096_SHA512 (4):
+                RSASSA-PSS 4096 bit key with a SHA512 digest.
+            RSA_SIGN_PKCS1_2048_SHA256 (5):
+                RSASSA-PKCS1-v1_5 with a 2048 bit key and a SHA256 digest.
+            RSA_SIGN_PKCS1_3072_SHA256 (6):
+                RSASSA-PKCS1-v1_5 with a 3072 bit key and a SHA256 digest.
+            RSA_SIGN_PKCS1_4096_SHA256 (7):
+                RSASSA-PKCS1-v1_5 with a 4096 bit key and a SHA256 digest.
+            RSA_SIGN_PKCS1_4096_SHA512 (8):
+                RSASSA-PKCS1-v1_5 with a 4096 bit key and a SHA512 digest.
+            ECDSA_P256_SHA256 (9):
+                ECDSA on the NIST P-256 curve with a SHA256
+                digest.
+            EC_SIGN_P256_SHA256 (9):
+                ECDSA on the NIST P-256 curve with a SHA256
+                digest.
+            ECDSA_P384_SHA384 (10):
+                ECDSA on the NIST P-384 curve with a SHA384
+                digest.
+            EC_SIGN_P384_SHA384 (10):
+                ECDSA on the NIST P-384 curve with a SHA384
+                digest.
+            ECDSA_P521_SHA512 (11):
+                ECDSA on the NIST P-521 curve with a SHA512
+                digest.
+            EC_SIGN_P521_SHA512 (11):
+                ECDSA on the NIST P-521 curve with a SHA512
+                digest.
         """
         _pb_options = {"allow_alias": True}
         SIGNATURE_ALGORITHM_UNSPECIFIED = 0
@@ -382,11 +463,11 @@ class PkixPublicKey(proto.Message):
         ECDSA_P521_SHA512 = 11
         EC_SIGN_P521_SHA512 = 11
 
-    public_key_pem = proto.Field(
+    public_key_pem: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    signature_algorithm = proto.Field(
+    signature_algorithm: SignatureAlgorithm = proto.Field(
         proto.ENUM,
         number=2,
         enum=SignatureAlgorithm,
@@ -440,20 +521,20 @@ class AttestorPublicKey(proto.Message):
             This field is a member of `oneof`_ ``public_key``.
     """
 
-    comment = proto.Field(
+    comment: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    id = proto.Field(
+    id: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    ascii_armored_pgp_public_key = proto.Field(
+    ascii_armored_pgp_public_key: str = proto.Field(
         proto.STRING,
         number=3,
         oneof="public_key",
     )
-    pkix_public_key = proto.Field(
+    pkix_public_key: "PkixPublicKey" = proto.Field(
         proto.MESSAGE,
         number=5,
         oneof="public_key",
