@@ -22,6 +22,8 @@ try:
 except ImportError:  # pragma: NO COVER
     import mock
 
+from collections.abc import Iterable
+import json
 import math
 
 from google.api_core import gapic_v1, grpc_helpers, grpc_helpers_async, path_template
@@ -31,12 +33,15 @@ import google.auth
 from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
 from google.oauth2 import service_account
+from google.protobuf import json_format
 from google.protobuf import timestamp_pb2  # type: ignore
 import grpc
 from grpc.experimental import aio
 from proto.marshal.rules import wrappers
 from proto.marshal.rules.dates import DurationRule, TimestampRule
 import pytest
+from requests import PreparedRequest, Request, Response
+from requests.sessions import Session
 
 from google.cloud.binaryauthorization_v1.services.system_policy_v1 import (
     SystemPolicyV1AsyncClient,
@@ -95,6 +100,7 @@ def test__get_default_mtls_endpoint():
     [
         (SystemPolicyV1Client, "grpc"),
         (SystemPolicyV1AsyncClient, "grpc_asyncio"),
+        (SystemPolicyV1Client, "rest"),
     ],
 )
 def test_system_policy_v1_client_from_service_account_info(
@@ -110,7 +116,11 @@ def test_system_policy_v1_client_from_service_account_info(
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == ("binaryauthorization.googleapis.com:443")
+        assert client.transport._host == (
+            "binaryauthorization.googleapis.com:443"
+            if transport_name in ["grpc", "grpc_asyncio"]
+            else "https://binaryauthorization.googleapis.com"
+        )
 
 
 @pytest.mark.parametrize(
@@ -118,6 +128,7 @@ def test_system_policy_v1_client_from_service_account_info(
     [
         (transports.SystemPolicyV1GrpcTransport, "grpc"),
         (transports.SystemPolicyV1GrpcAsyncIOTransport, "grpc_asyncio"),
+        (transports.SystemPolicyV1RestTransport, "rest"),
     ],
 )
 def test_system_policy_v1_client_service_account_always_use_jwt(
@@ -143,6 +154,7 @@ def test_system_policy_v1_client_service_account_always_use_jwt(
     [
         (SystemPolicyV1Client, "grpc"),
         (SystemPolicyV1AsyncClient, "grpc_asyncio"),
+        (SystemPolicyV1Client, "rest"),
     ],
 )
 def test_system_policy_v1_client_from_service_account_file(
@@ -165,13 +177,18 @@ def test_system_policy_v1_client_from_service_account_file(
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == ("binaryauthorization.googleapis.com:443")
+        assert client.transport._host == (
+            "binaryauthorization.googleapis.com:443"
+            if transport_name in ["grpc", "grpc_asyncio"]
+            else "https://binaryauthorization.googleapis.com"
+        )
 
 
 def test_system_policy_v1_client_get_transport_class():
     transport = SystemPolicyV1Client.get_transport_class()
     available_transports = [
         transports.SystemPolicyV1GrpcTransport,
+        transports.SystemPolicyV1RestTransport,
     ]
     assert transport in available_transports
 
@@ -188,6 +205,7 @@ def test_system_policy_v1_client_get_transport_class():
             transports.SystemPolicyV1GrpcAsyncIOTransport,
             "grpc_asyncio",
         ),
+        (SystemPolicyV1Client, transports.SystemPolicyV1RestTransport, "rest"),
     ],
 )
 @mock.patch.object(
@@ -333,6 +351,8 @@ def test_system_policy_v1_client_client_options(
             "grpc_asyncio",
             "false",
         ),
+        (SystemPolicyV1Client, transports.SystemPolicyV1RestTransport, "rest", "true"),
+        (SystemPolicyV1Client, transports.SystemPolicyV1RestTransport, "rest", "false"),
     ],
 )
 @mock.patch.object(
@@ -532,6 +552,7 @@ def test_system_policy_v1_client_get_mtls_endpoint_and_cert_source(client_class)
             transports.SystemPolicyV1GrpcAsyncIOTransport,
             "grpc_asyncio",
         ),
+        (SystemPolicyV1Client, transports.SystemPolicyV1RestTransport, "rest"),
     ],
 )
 def test_system_policy_v1_client_client_options_scopes(
@@ -572,6 +593,7 @@ def test_system_policy_v1_client_client_options_scopes(
             "grpc_asyncio",
             grpc_helpers_async,
         ),
+        (SystemPolicyV1Client, transports.SystemPolicyV1RestTransport, "rest", None),
     ],
 )
 def test_system_policy_v1_client_client_options_credentials_file(
@@ -940,6 +962,275 @@ async def test_get_system_policy_flattened_error_async():
         )
 
 
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        service.GetSystemPolicyRequest,
+        dict,
+    ],
+)
+def test_get_system_policy_rest(request_type):
+    client = SystemPolicyV1Client(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="rest",
+    )
+
+    # send a request that will satisfy transcoding
+    request_init = {"name": "locations/sample1/policy"}
+    request = request_type(**request_init)
+
+    # Mock the http request call within the method and fake a response.
+    with mock.patch.object(type(client.transport._session), "request") as req:
+        # Designate an appropriate value for the returned response.
+        return_value = resources.Policy(
+            name="name_value",
+            description="description_value",
+            global_policy_evaluation_mode=resources.Policy.GlobalPolicyEvaluationMode.ENABLE,
+        )
+
+        # Wrap the value into a proper Response obj
+        response_value = Response()
+        response_value.status_code = 200
+        pb_return_value = resources.Policy.pb(return_value)
+        json_return_value = json_format.MessageToJson(pb_return_value)
+
+        response_value._content = json_return_value.encode("UTF-8")
+        req.return_value = response_value
+        response = client.get_system_policy(request)
+
+    # Establish that the response is the type that we expect.
+    assert isinstance(response, resources.Policy)
+    assert response.name == "name_value"
+    assert response.description == "description_value"
+    assert (
+        response.global_policy_evaluation_mode
+        == resources.Policy.GlobalPolicyEvaluationMode.ENABLE
+    )
+
+
+def test_get_system_policy_rest_required_fields(
+    request_type=service.GetSystemPolicyRequest,
+):
+    transport_class = transports.SystemPolicyV1RestTransport
+
+    request_init = {}
+    request_init["name"] = ""
+    request = request_type(**request_init)
+    pb_request = request_type.pb(request)
+    jsonified_request = json.loads(
+        json_format.MessageToJson(
+            pb_request,
+            including_default_value_fields=False,
+            use_integers_for_enums=False,
+        )
+    )
+
+    # verify fields with default values are dropped
+
+    unset_fields = transport_class(
+        credentials=ga_credentials.AnonymousCredentials()
+    ).get_system_policy._get_unset_required_fields(jsonified_request)
+    jsonified_request.update(unset_fields)
+
+    # verify required fields with default values are now present
+
+    jsonified_request["name"] = "name_value"
+
+    unset_fields = transport_class(
+        credentials=ga_credentials.AnonymousCredentials()
+    ).get_system_policy._get_unset_required_fields(jsonified_request)
+    jsonified_request.update(unset_fields)
+
+    # verify required fields with non-default values are left alone
+    assert "name" in jsonified_request
+    assert jsonified_request["name"] == "name_value"
+
+    client = SystemPolicyV1Client(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="rest",
+    )
+    request = request_type(**request_init)
+
+    # Designate an appropriate value for the returned response.
+    return_value = resources.Policy()
+    # Mock the http request call within the method and fake a response.
+    with mock.patch.object(Session, "request") as req:
+        # We need to mock transcode() because providing default values
+        # for required fields will fail the real version if the http_options
+        # expect actual values for those fields.
+        with mock.patch.object(path_template, "transcode") as transcode:
+            # A uri without fields and an empty body will force all the
+            # request fields to show up in the query_params.
+            pb_request = request_type.pb(request)
+            transcode_result = {
+                "uri": "v1/sample_method",
+                "method": "get",
+                "query_params": pb_request,
+            }
+            transcode.return_value = transcode_result
+
+            response_value = Response()
+            response_value.status_code = 200
+
+            pb_return_value = resources.Policy.pb(return_value)
+            json_return_value = json_format.MessageToJson(pb_return_value)
+
+            response_value._content = json_return_value.encode("UTF-8")
+            req.return_value = response_value
+
+            response = client.get_system_policy(request)
+
+            expected_params = [("$alt", "json;enum-encoding=int")]
+            actual_params = req.call_args.kwargs["params"]
+            assert expected_params == actual_params
+
+
+def test_get_system_policy_rest_unset_required_fields():
+    transport = transports.SystemPolicyV1RestTransport(
+        credentials=ga_credentials.AnonymousCredentials
+    )
+
+    unset_fields = transport.get_system_policy._get_unset_required_fields({})
+    assert set(unset_fields) == (set(()) & set(("name",)))
+
+
+@pytest.mark.parametrize("null_interceptor", [True, False])
+def test_get_system_policy_rest_interceptors(null_interceptor):
+    transport = transports.SystemPolicyV1RestTransport(
+        credentials=ga_credentials.AnonymousCredentials(),
+        interceptor=None
+        if null_interceptor
+        else transports.SystemPolicyV1RestInterceptor(),
+    )
+    client = SystemPolicyV1Client(transport=transport)
+    with mock.patch.object(
+        type(client.transport._session), "request"
+    ) as req, mock.patch.object(
+        path_template, "transcode"
+    ) as transcode, mock.patch.object(
+        transports.SystemPolicyV1RestInterceptor, "post_get_system_policy"
+    ) as post, mock.patch.object(
+        transports.SystemPolicyV1RestInterceptor, "pre_get_system_policy"
+    ) as pre:
+        pre.assert_not_called()
+        post.assert_not_called()
+        pb_message = service.GetSystemPolicyRequest.pb(service.GetSystemPolicyRequest())
+        transcode.return_value = {
+            "method": "post",
+            "uri": "my_uri",
+            "body": pb_message,
+            "query_params": pb_message,
+        }
+
+        req.return_value = Response()
+        req.return_value.status_code = 200
+        req.return_value.request = PreparedRequest()
+        req.return_value._content = resources.Policy.to_json(resources.Policy())
+
+        request = service.GetSystemPolicyRequest()
+        metadata = [
+            ("key", "val"),
+            ("cephalopod", "squid"),
+        ]
+        pre.return_value = request, metadata
+        post.return_value = resources.Policy()
+
+        client.get_system_policy(
+            request,
+            metadata=[
+                ("key", "val"),
+                ("cephalopod", "squid"),
+            ],
+        )
+
+        pre.assert_called_once()
+        post.assert_called_once()
+
+
+def test_get_system_policy_rest_bad_request(
+    transport: str = "rest", request_type=service.GetSystemPolicyRequest
+):
+    client = SystemPolicyV1Client(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
+    )
+
+    # send a request that will satisfy transcoding
+    request_init = {"name": "locations/sample1/policy"}
+    request = request_type(**request_init)
+
+    # Mock the http request call within the method and fake a BadRequest error.
+    with mock.patch.object(Session, "request") as req, pytest.raises(
+        core_exceptions.BadRequest
+    ):
+        # Wrap the value into a proper Response obj
+        response_value = Response()
+        response_value.status_code = 400
+        response_value.request = Request()
+        req.return_value = response_value
+        client.get_system_policy(request)
+
+
+def test_get_system_policy_rest_flattened():
+    client = SystemPolicyV1Client(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="rest",
+    )
+
+    # Mock the http request call within the method and fake a response.
+    with mock.patch.object(type(client.transport._session), "request") as req:
+        # Designate an appropriate value for the returned response.
+        return_value = resources.Policy()
+
+        # get arguments that satisfy an http rule for this method
+        sample_request = {"name": "locations/sample1/policy"}
+
+        # get truthy value for each flattened field
+        mock_args = dict(
+            name="name_value",
+        )
+        mock_args.update(sample_request)
+
+        # Wrap the value into a proper Response obj
+        response_value = Response()
+        response_value.status_code = 200
+        pb_return_value = resources.Policy.pb(return_value)
+        json_return_value = json_format.MessageToJson(pb_return_value)
+        response_value._content = json_return_value.encode("UTF-8")
+        req.return_value = response_value
+
+        client.get_system_policy(**mock_args)
+
+        # Establish that the underlying call was made with the expected
+        # request object values.
+        assert len(req.mock_calls) == 1
+        _, args, _ = req.mock_calls[0]
+        assert path_template.validate(
+            "%s/v1/{name=locations/*/policy}" % client.transport._host, args[1]
+        )
+
+
+def test_get_system_policy_rest_flattened_error(transport: str = "rest"):
+    client = SystemPolicyV1Client(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
+    )
+
+    # Attempting to call a method with both a request object and flattened
+    # fields is an error.
+    with pytest.raises(ValueError):
+        client.get_system_policy(
+            service.GetSystemPolicyRequest(),
+            name="name_value",
+        )
+
+
+def test_get_system_policy_rest_error():
+    client = SystemPolicyV1Client(
+        credentials=ga_credentials.AnonymousCredentials(), transport="rest"
+    )
+
+
 def test_credentials_transport_error():
     # It is an error to provide credentials and a transport instance.
     transport = transports.SystemPolicyV1GrpcTransport(
@@ -1021,6 +1312,7 @@ def test_transport_get_channel():
     [
         transports.SystemPolicyV1GrpcTransport,
         transports.SystemPolicyV1GrpcAsyncIOTransport,
+        transports.SystemPolicyV1RestTransport,
     ],
 )
 def test_transport_adc(transport_class):
@@ -1035,6 +1327,7 @@ def test_transport_adc(transport_class):
     "transport_name",
     [
         "grpc",
+        "rest",
     ],
 )
 def test_transport_kind(transport_name):
@@ -1162,6 +1455,7 @@ def test_system_policy_v1_transport_auth_adc(transport_class):
     [
         transports.SystemPolicyV1GrpcTransport,
         transports.SystemPolicyV1GrpcAsyncIOTransport,
+        transports.SystemPolicyV1RestTransport,
     ],
 )
 def test_system_policy_v1_transport_auth_gdch_credentials(transport_class):
@@ -1259,11 +1553,23 @@ def test_system_policy_v1_grpc_transport_client_cert_source_for_mtls(transport_c
             )
 
 
+def test_system_policy_v1_http_transport_client_cert_source_for_mtls():
+    cred = ga_credentials.AnonymousCredentials()
+    with mock.patch(
+        "google.auth.transport.requests.AuthorizedSession.configure_mtls_channel"
+    ) as mock_configure_mtls_channel:
+        transports.SystemPolicyV1RestTransport(
+            credentials=cred, client_cert_source_for_mtls=client_cert_source_callback
+        )
+        mock_configure_mtls_channel.assert_called_once_with(client_cert_source_callback)
+
+
 @pytest.mark.parametrize(
     "transport_name",
     [
         "grpc",
         "grpc_asyncio",
+        "rest",
     ],
 )
 def test_system_policy_v1_host_no_port(transport_name):
@@ -1274,7 +1580,11 @@ def test_system_policy_v1_host_no_port(transport_name):
         ),
         transport=transport_name,
     )
-    assert client.transport._host == ("binaryauthorization.googleapis.com:443")
+    assert client.transport._host == (
+        "binaryauthorization.googleapis.com:443"
+        if transport_name in ["grpc", "grpc_asyncio"]
+        else "https://binaryauthorization.googleapis.com"
+    )
 
 
 @pytest.mark.parametrize(
@@ -1282,6 +1592,7 @@ def test_system_policy_v1_host_no_port(transport_name):
     [
         "grpc",
         "grpc_asyncio",
+        "rest",
     ],
 )
 def test_system_policy_v1_host_with_port(transport_name):
@@ -1292,7 +1603,33 @@ def test_system_policy_v1_host_with_port(transport_name):
         ),
         transport=transport_name,
     )
-    assert client.transport._host == ("binaryauthorization.googleapis.com:8000")
+    assert client.transport._host == (
+        "binaryauthorization.googleapis.com:8000"
+        if transport_name in ["grpc", "grpc_asyncio"]
+        else "https://binaryauthorization.googleapis.com:8000"
+    )
+
+
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "rest",
+    ],
+)
+def test_system_policy_v1_client_transport_session_collision(transport_name):
+    creds1 = ga_credentials.AnonymousCredentials()
+    creds2 = ga_credentials.AnonymousCredentials()
+    client1 = SystemPolicyV1Client(
+        credentials=creds1,
+        transport=transport_name,
+    )
+    client2 = SystemPolicyV1Client(
+        credentials=creds2,
+        transport=transport_name,
+    )
+    session1 = client1.transport.get_system_policy._session
+    session2 = client2.transport.get_system_policy._session
+    assert session1 != session2
 
 
 def test_system_policy_v1_grpc_transport_channel():
@@ -1583,6 +1920,7 @@ async def test_transport_close_async():
 
 def test_transport_close():
     transports = {
+        "rest": "_session",
         "grpc": "_grpc_channel",
     }
 
@@ -1600,6 +1938,7 @@ def test_transport_close():
 
 def test_client_ctx():
     transports = [
+        "rest",
         "grpc",
     ]
     for transport in transports:
